# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_auto_text_group import XAutoTextGroup as XAutoTextGroup_c9770c70

class XAutoTextContainer(XNameAccess_e2ab0cf6):
    """
    handles blocks of AutoTextEntry.

    See Also:
        `API XAutoTextContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XAutoTextContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XAutoTextContainer'

    @abstractmethod
    def insertNewByName(self, aGroupName: str) -> 'XAutoTextGroup_c9770c70':
        """
        creates a new AutoText group.
        
        The name must follow the pattern groupname*pathid, where:
        
        If only groupname is specified, the path defaults to 0, the Office Basis layer.
        Note that in some systems the user may lack of write access to the Office Basis directory.
        
        Example:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    @abstractmethod
    def removeByName(self, aGroupName: str) -> None:
        """
        deletes the specified AutoText group.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """

__all__ = ['XAutoTextContainer']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ....dyn.script.vba.vba_event_id import VBAEventId as VBAEventId
from ....dyn.script.vba.vba_event_id import VBAEventIdEnum as VBAEventIdEnum
from ....dyn.script.vba.vba_event_processor import VBAEventProcessor as VBAEventProcessor
from ....dyn.script.vba.vba_macro_resolver import VBAMacroResolver as VBAMacroResolver
from ....dyn.script.vba.vba_script_event import VBAScriptEvent as VBAScriptEvent
from ....dyn.script.vba.vba_script_event_id import VBAScriptEventId as VBAScriptEventId
from ....dyn.script.vba.vba_script_event_id import VBAScriptEventIdEnum as VBAScriptEventIdEnum
from ....dyn.script.vba.vba_spreadsheet_event_processor import VBASpreadsheetEventProcessor as VBASpreadsheetEventProcessor
from ....dyn.script.vba.vba_text_event_processor import VBATextEventProcessor as VBATextEventProcessor
from ....dyn.script.vba.xvba_compatibility import XVBACompatibility as XVBACompatibility
from ....dyn.script.vba.xvba_event_processor import XVBAEventProcessor as XVBAEventProcessor
from ....dyn.script.vba.xvba_macro_resolver import XVBAMacroResolver as XVBAMacroResolver
from ....dyn.script.vba.xvba_module_info import XVBAModuleInfo as XVBAModuleInfo
from ....dyn.script.vba.xvba_script_listener import XVBAScriptListener as XVBAScriptListener



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.table
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class XTablePivotCharts(XNameAccess_e2ab0cf6):
    """
    provides methods to access pivot charts via name and to insert and remove pivot charts.
    
    **since**
    
        LibreOffice 5.4

    See Also:
        `API XTablePivotCharts <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XTablePivotCharts.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XTablePivotCharts'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XTablePivotCharts'

    @abstractmethod
    def addNewByName(self, aName: str, aRect: 'Rectangle_84b109e9', aPivotTableName: str) -> None:
        """
        creates a pivot chart and adds it to the collection.
        """
    @abstractmethod
    def removeByName(self, aName: str) -> None:
        """
        removes a pivot chart from the collection.
        """

__all__ = ['XTablePivotCharts']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XMetricField(XInterface_8f010a43):
    """
    gives access to the value and formatting of a metric field.

    See Also:
        `API XMetricField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XMetricField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XMetricField'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XMetricField'

    @abstractmethod
    def getCorrectedValue(self, FieldUnit: int) -> int:
        """
        returns the corrected value which is displayed in the metric field.
        """
    @abstractmethod
    def getDecimalDigits(self) -> int:
        """
        returns the currently set number of decimals.
        """
    @abstractmethod
    def getFirst(self, FieldUnit: int) -> int:
        """
        returns the currently set first value which is set on POS1 key.
        """
    @abstractmethod
    def getLast(self, FieldUnit: int) -> int:
        """
        returns the currently set last value which is set on END key.
        """
    @abstractmethod
    def getMax(self, FieldUnit: int) -> int:
        """
        returns the currently set maximum value that can be entered by the user.
        """
    @abstractmethod
    def getMin(self, FieldUnit: int) -> int:
        """
        returns the currently set minimum value that can be entered by the user.
        """
    @abstractmethod
    def getSpinSize(self) -> int:
        """
        returns the currently set increment value for the spin button.
        """
    @abstractmethod
    def getValue(self, FieldUnit: int) -> int:
        """
        returns the value which is currently displayed in the metric field.
        """
    @abstractmethod
    def isStrictFormat(self) -> bool:
        """
        returns whether the format is currently checked during user input.
        """
    @abstractmethod
    def setDecimalDigits(self, nDigits: int) -> None:
        """
        sets the number of decimals.
        """
    @abstractmethod
    def setFirst(self, Value: int, FieldUnit: int) -> None:
        """
        sets the first value to be set on POS1 key.
        """
    @abstractmethod
    def setLast(self, Value: int, FieldUnit: int) -> None:
        """
        sets the last value to be set on END key.
        """
    @abstractmethod
    def setMax(self, Value: int, FieldUnit: int) -> None:
        """
        sets the maximum value that can be entered by the user.
        """
    @abstractmethod
    def setMin(self, Value: int, FieldUnit: int) -> None:
        """
        sets the minimum value that can be entered by the user.
        """
    @abstractmethod
    def setSpinSize(self, Value: int) -> None:
        """
        sets the increment value for the spin button.
        """
    @abstractmethod
    def setStrictFormat(self, bStrict: bool) -> None:
        """
        determines if the format is checked during user input.
        """
    @abstractmethod
    def setUserValue(self, Value: int, FieldUnit: int) -> None:
        """
        sets the user value which is displayed in the metric field.
        """
    @abstractmethod
    def setValue(self, Value: int, FieldUnit: int) -> None:
        """
        sets the value which is displayed in the metric field.
        """

__all__ = ['XMetricField']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text


class SizeType(object):
    """
    Const Class

    The height value of objects like text frames or table rows may be interpreted in different ways.
    
    The values may specify the absolute height (SIZETYPE_FIX), the minimum height (SIZETYPE_MIN), or they are ignored (SIZETYPE_VAR), in which case the real height depends on the content. This information is contained in a property called \"SizeType\".

    See Also:
        `API SizeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1SizeType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.SizeType'
    __ooo_type_name__: str = 'const'

    VARIABLE = 0
    FIX = 1
    MIN = 2
    """
    The height property determines the minimum height of the object, but the actual height will be increased if the content demands it.
    """

__all__ = ['SizeType']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.presentation
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.presentation import EffectPresetClass as EffectPresetClass
    if hasattr(EffectPresetClass, '_constants') and isinstance(EffectPresetClass._constants, dict):
        EffectPresetClass._constants['__ooo_ns__'] = 'com.sun.star.presentation'
        EffectPresetClass._constants['__ooo_full_ns__'] = 'com.sun.star.presentation.EffectPresetClass'
        EffectPresetClass._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global EffectPresetClassEnum
        ls = [f for f in dir(EffectPresetClass) if not callable(getattr(EffectPresetClass, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(EffectPresetClass, name)
        EffectPresetClassEnum = IntEnum('EffectPresetClassEnum', _dict)
    build_enum()
else:
    from ...lo.presentation.effect_preset_class import EffectPresetClass as EffectPresetClass

    class EffectPresetClassEnum(IntEnum):
        """
        Enum of Const Class EffectPresetClass

        This constants defines the class for a preset animation effect.
        
        This is stored with the name preset-class inside the com.sun.star.animations.XAnimationNode.UserData sequence.
        This does not manipulate the timing or synchronization. It can be used to quickly identify preset animations inside an animation hierarchy.
        """
        CUSTOM = EffectPresetClass.CUSTOM
        ENTRANCE = EffectPresetClass.ENTRANCE
        EXIT = EffectPresetClass.EXIT
        EMPHASIS = EffectPresetClass.EMPHASIS
        MOTIONPATH = EffectPresetClass.MOTIONPATH
        OLEACTION = EffectPresetClass.OLEACTION
        MEDIACALL = EffectPresetClass.MEDIACALL

__all__ = ['EffectPresetClass', 'EffectPresetClassEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text.textfield
from abc import abstractproperty
from ..text_field import TextField as TextField_90260a56

class Macro(TextField_90260a56):
    """
    Service Class

    specifies service of a macro text field.

    See Also:
        `API Macro <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Macro.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.Macro'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Hint(self) -> str:
        """
        contains a tip that is displayed at the user interface.
        """

    @abstractproperty
    def MacroLibrary(self) -> str:
        """
        contains the library name of a StarBASIC macro.
        """

    @abstractproperty
    def MacroName(self) -> str:
        """
        contains the macro name of a StarBASIC macro.
        """



__all__ = ['Macro']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.awt import FontWeight as FontWeight
    if hasattr(FontWeight, '_constants') and isinstance(FontWeight._constants, dict):
        FontWeight._constants['__ooo_ns__'] = 'com.sun.star.awt'
        FontWeight._constants['__ooo_full_ns__'] = 'com.sun.star.awt.FontWeight'
        FontWeight._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global FontWeightEnum
        ls = [f for f in dir(FontWeight) if not callable(getattr(FontWeight, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(FontWeight, name)
        FontWeightEnum = IntEnum('FontWeightEnum', _dict)
    build_enum()
else:
    from ...lo.awt.font_weight import FontWeight as FontWeight

    class FontWeightEnum(IntEnum):
        """
        Enum of Const Class FontWeight

        These values are used to specify whether a font is thin or bold.
        
        They may be expanded in future versions.
        """
        DONTKNOW = FontWeight.DONTKNOW
        """
        The font weight is not specified/known.
        """
        THIN = FontWeight.THIN
        """
        specifies a 50% font weight.
        """
        ULTRALIGHT = FontWeight.ULTRALIGHT
        """
        specifies a 60% font weight.
        """
        LIGHT = FontWeight.LIGHT
        """
        specifies a 75% font weight.
        """
        SEMILIGHT = FontWeight.SEMILIGHT
        """
        specifies a 90% font weight.
        """
        NORMAL = FontWeight.NORMAL
        """
        specifies a normal font weight.
        """
        SEMIBOLD = FontWeight.SEMIBOLD
        """
        specifies a 110% font weight.
        """
        BOLD = FontWeight.BOLD
        """
        specifies a 150% font weight.
        """
        ULTRABOLD = FontWeight.ULTRABOLD
        """
        specifies a 175% font weight.
        """
        BLACK = FontWeight.BLACK
        """
        specifies a 200% font weight.
        """

__all__ = ['FontWeight', 'FontWeightEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.embed import VerbAttributes as VerbAttributes
    if hasattr(VerbAttributes, '_constants') and isinstance(VerbAttributes._constants, dict):
        VerbAttributes._constants['__ooo_ns__'] = 'com.sun.star.embed'
        VerbAttributes._constants['__ooo_full_ns__'] = 'com.sun.star.embed.VerbAttributes'
        VerbAttributes._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global VerbAttributesEnum
        ls = [f for f in dir(VerbAttributes) if not callable(getattr(VerbAttributes, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(VerbAttributes, name)
        VerbAttributesEnum = IntFlag('VerbAttributesEnum', _dict)
    build_enum()
else:
    from ...lo.embed.verb_attributes import VerbAttributes as VerbAttributes

    class VerbAttributesEnum(IntFlag):
        """
        Enum of Const Class VerbAttributes

        The constant set specifies possible attributes of a verb.
        """
        MS_VERBATTR_NEVERDIRTIES = VerbAttributes.MS_VERBATTR_NEVERDIRTIES
        """
        Execution of the verb with this attribute must not modify the object.
        """
        MS_VERBATTR_ONCONTAINERMENU = VerbAttributes.MS_VERBATTR_ONCONTAINERMENU
        """
        indicates that the verb should appear in the object's menu.
        """

__all__ = ['VerbAttributes', 'VerbAttributesEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from abc import abstractmethod
from .x_font import XFont as XFont_5f480843

class XFont2(XFont_5f480843):
    """
    extends the XFont interface and provides additional information for a font.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XFont2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XFont2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XFont2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XFont2'

    @abstractmethod
    def hasGlyphs(self, aText: str) -> bool:
        """
        checks whether or not this font has all the glyphs for the text specified by aText.
        """

__all__ = ['XFont2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.drawing.ColorMode import (GREYS, MONO, STANDARD, WATERMARK)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.drawing.ColorMode Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.drawing",
            "__ooo_full_ns__": "com.sun.star.drawing.ColorMode",
            "__ooo_type_name__": "enum",
            "GREYS": GREYS,
            "MONO": MONO,
            "STANDARD": STANDARD,
            "WATERMARK": WATERMARK,
        }
        result = type('ColorMode', (object,), _dict)
        return result

    ColorMode = _get_enum()
else:
    from ...lo.drawing.color_mode import ColorMode as ColorMode

__all__ = ['ColorMode']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.drawing.accessible_draw_document_view import AccessibleDrawDocumentView as AccessibleDrawDocumentView
from ...dyn.drawing.accessible_graph_control import AccessibleGraphControl as AccessibleGraphControl
from ...dyn.drawing.accessible_graphic_shape import AccessibleGraphicShape as AccessibleGraphicShape
from ...dyn.drawing.accessible_image_bullet import AccessibleImageBullet as AccessibleImageBullet
from ...dyn.drawing.accessible_ole_shape import AccessibleOLEShape as AccessibleOLEShape
from ...dyn.drawing.accessible_shape import AccessibleShape as AccessibleShape
from ...dyn.drawing.accessible_slide_view import AccessibleSlideView as AccessibleSlideView
from ...dyn.drawing.accessible_slide_view_object import AccessibleSlideViewObject as AccessibleSlideViewObject
from ...dyn.drawing.alignment import Alignment as Alignment
from ...dyn.drawing.applet_shape import AppletShape as AppletShape
from ...dyn.drawing.arrangement import Arrangement as Arrangement
from ...dyn.drawing.background import Background as Background
from ...dyn.drawing.bar_code import BarCode as BarCode
from ...dyn.drawing.bar_code_error_correction import BarCodeErrorCorrection as BarCodeErrorCorrection
from ...dyn.drawing.bar_code_error_correction import BarCodeErrorCorrectionEnum as BarCodeErrorCorrectionEnum
from ...dyn.drawing.bezier_point import BezierPoint as BezierPoint
from ...dyn.drawing.bitmap_mode import BitmapMode as BitmapMode
from ...dyn.drawing.bitmap_table import BitmapTable as BitmapTable
from ...dyn.drawing.bound_volume import BoundVolume as BoundVolume
from ...dyn.drawing.camera_geometry import CameraGeometry as CameraGeometry
from ...dyn.drawing.canvas_feature import CanvasFeature as CanvasFeature
from ...dyn.drawing.canvas_feature import CanvasFeatureEnum as CanvasFeatureEnum
from ...dyn.drawing.caption_escape_direction import CaptionEscapeDirection as CaptionEscapeDirection
from ...dyn.drawing.caption_escape_direction import CaptionEscapeDirectionEnum as CaptionEscapeDirectionEnum
from ...dyn.drawing.caption_shape import CaptionShape as CaptionShape
from ...dyn.drawing.caption_type import CaptionType as CaptionType
from ...dyn.drawing.caption_type import CaptionTypeEnum as CaptionTypeEnum
from ...dyn.drawing.circle_kind import CircleKind as CircleKind
from ...dyn.drawing.closed_bezier_shape import ClosedBezierShape as ClosedBezierShape
from ...dyn.drawing.color_mode import ColorMode as ColorMode
from ...dyn.drawing.color_table import ColorTable as ColorTable
from ...dyn.drawing.connection_type import ConnectionType as ConnectionType
from ...dyn.drawing.connector_properties import ConnectorProperties as ConnectorProperties
from ...dyn.drawing.connector_shape import ConnectorShape as ConnectorShape
from ...dyn.drawing.connector_type import ConnectorType as ConnectorType
from ...dyn.drawing.control_shape import ControlShape as ControlShape
from ...dyn.drawing.coordinate_sequence import CoordinateSequence as CoordinateSequence
from ...dyn.drawing.coordinate_sequence_sequence import CoordinateSequenceSequence as CoordinateSequenceSequence
from ...dyn.drawing.custom_shape import CustomShape as CustomShape
from ...dyn.drawing.custom_shape_engine import CustomShapeEngine as CustomShapeEngine
from ...dyn.drawing.dash_style import DashStyle as DashStyle
from ...dyn.drawing.dash_table import DashTable as DashTable
from ...dyn.drawing.defaults import Defaults as Defaults
from ...dyn.drawing.direction3_d import Direction3D as Direction3D
from ...dyn.drawing.document_settings import DocumentSettings as DocumentSettings
from ...dyn.drawing.double_sequence import DoubleSequence as DoubleSequence
from ...dyn.drawing.double_sequence_sequence import DoubleSequenceSequence as DoubleSequenceSequence
from ...dyn.drawing.draw_page import DrawPage as DrawPage
from ...dyn.drawing.draw_pages import DrawPages as DrawPages
from ...dyn.drawing.draw_view_mode import DrawViewMode as DrawViewMode
from ...dyn.drawing.drawing_document import DrawingDocument as DrawingDocument
from ...dyn.drawing.drawing_document_draw_view import DrawingDocumentDrawView as DrawingDocumentDrawView
from ...dyn.drawing.drawing_document_factory import DrawingDocumentFactory as DrawingDocumentFactory
from ...dyn.drawing.ellipse_shape import EllipseShape as EllipseShape
from ...dyn.drawing.enhanced_custom_shape_adjustment_value import EnhancedCustomShapeAdjustmentValue as EnhancedCustomShapeAdjustmentValue
from ...dyn.drawing.enhanced_custom_shape_extrusion import EnhancedCustomShapeExtrusion as EnhancedCustomShapeExtrusion
from ...dyn.drawing.enhanced_custom_shape_geometry import EnhancedCustomShapeGeometry as EnhancedCustomShapeGeometry
from ...dyn.drawing.enhanced_custom_shape_glue_point_type import EnhancedCustomShapeGluePointType as EnhancedCustomShapeGluePointType
from ...dyn.drawing.enhanced_custom_shape_glue_point_type import EnhancedCustomShapeGluePointTypeEnum as EnhancedCustomShapeGluePointTypeEnum
from ...dyn.drawing.enhanced_custom_shape_handle import EnhancedCustomShapeHandle as EnhancedCustomShapeHandle
from ...dyn.drawing.enhanced_custom_shape_parameter import EnhancedCustomShapeParameter as EnhancedCustomShapeParameter
from ...dyn.drawing.enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair
from ...dyn.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterType as EnhancedCustomShapeParameterType
from ...dyn.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterTypeEnum as EnhancedCustomShapeParameterTypeEnum
from ...dyn.drawing.enhanced_custom_shape_path import EnhancedCustomShapePath as EnhancedCustomShapePath
from ...dyn.drawing.enhanced_custom_shape_segment import EnhancedCustomShapeSegment as EnhancedCustomShapeSegment
from ...dyn.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommand as EnhancedCustomShapeSegmentCommand
from ...dyn.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommandEnum as EnhancedCustomShapeSegmentCommandEnum
from ...dyn.drawing.enhanced_custom_shape_text_frame import EnhancedCustomShapeTextFrame as EnhancedCustomShapeTextFrame
from ...dyn.drawing.enhanced_custom_shape_text_path import EnhancedCustomShapeTextPath as EnhancedCustomShapeTextPath
from ...dyn.drawing.enhanced_custom_shape_text_path_mode import EnhancedCustomShapeTextPathMode as EnhancedCustomShapeTextPathMode
from ...dyn.drawing.escape_direction import EscapeDirection as EscapeDirection
from ...dyn.drawing.fill_properties import FillProperties as FillProperties
from ...dyn.drawing.fill_style import FillStyle as FillStyle
from ...dyn.drawing.flag_sequence import FlagSequence as FlagSequence
from ...dyn.drawing.flag_sequence_sequence import FlagSequenceSequence as FlagSequenceSequence
from ...dyn.drawing.generic_draw_page import GenericDrawPage as GenericDrawPage
from ...dyn.drawing.generic_drawing_document import GenericDrawingDocument as GenericDrawingDocument
from ...dyn.drawing.glue_point import GluePoint as GluePoint
from ...dyn.drawing.glue_point2 import GluePoint2 as GluePoint2
from ...dyn.drawing.gradient_table import GradientTable as GradientTable
from ...dyn.drawing.graphic_export_filter import GraphicExportFilter as GraphicExportFilter
from ...dyn.drawing.graphic_filter_request import GraphicFilterRequest as GraphicFilterRequest
from ...dyn.drawing.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
from ...dyn.drawing.group_shape import GroupShape as GroupShape
from ...dyn.drawing.hatch import Hatch as Hatch
from ...dyn.drawing.hatch_style import HatchStyle as HatchStyle
from ...dyn.drawing.hatch_table import HatchTable as HatchTable
from ...dyn.drawing.homogen_matrix import HomogenMatrix as HomogenMatrix
from ...dyn.drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3
from ...dyn.drawing.homogen_matrix4 import HomogenMatrix4 as HomogenMatrix4
from ...dyn.drawing.homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine
from ...dyn.drawing.homogen_matrix_line3 import HomogenMatrixLine3 as HomogenMatrixLine3
from ...dyn.drawing.homogen_matrix_line4 import HomogenMatrixLine4 as HomogenMatrixLine4
from ...dyn.drawing.horizontal_dimensioning import HorizontalDimensioning as HorizontalDimensioning
from ...dyn.drawing.layer import Layer as Layer
from ...dyn.drawing.layer_manager import LayerManager as LayerManager
from ...dyn.drawing.layer_type import LayerType as LayerType
from ...dyn.drawing.line_cap import LineCap as LineCap
from ...dyn.drawing.line_dash import LineDash as LineDash
from ...dyn.drawing.line_end_type import LineEndType as LineEndType
from ...dyn.drawing.line_joint import LineJoint as LineJoint
from ...dyn.drawing.line_properties import LineProperties as LineProperties
from ...dyn.drawing.line_shape import LineShape as LineShape
from ...dyn.drawing.line_style import LineStyle as LineStyle
from ...dyn.drawing.marker_table import MarkerTable as MarkerTable
from ...dyn.drawing.master_page import MasterPage as MasterPage
from ...dyn.drawing.master_pages import MasterPages as MasterPages
from ...dyn.drawing.measure_kind import MeasureKind as MeasureKind
from ...dyn.drawing.measure_properties import MeasureProperties as MeasureProperties
from ...dyn.drawing.measure_shape import MeasureShape as MeasureShape
from ...dyn.drawing.measure_text_horz_pos import MeasureTextHorzPos as MeasureTextHorzPos
from ...dyn.drawing.measure_text_vert_pos import MeasureTextVertPos as MeasureTextVertPos
from ...dyn.drawing.mirror_axis import MirrorAxis as MirrorAxis
from ...dyn.drawing.module_dispatcher import ModuleDispatcher as ModuleDispatcher
from ...dyn.drawing.normals_kind import NormalsKind as NormalsKind
from ...dyn.drawing.ole2_shape import OLE2Shape as OLE2Shape
from ...dyn.drawing.open_bezier_shape import OpenBezierShape as OpenBezierShape
from ...dyn.drawing.page_shape import PageShape as PageShape
from ...dyn.drawing.plugin_shape import PluginShape as PluginShape
from ...dyn.drawing.point_sequence import PointSequence as PointSequence
from ...dyn.drawing.point_sequence_sequence import PointSequenceSequence as PointSequenceSequence
from ...dyn.drawing.poly_line_shape import PolyLineShape as PolyLineShape
from ...dyn.drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords
from ...dyn.drawing.poly_polygon_bezier_descriptor import PolyPolygonBezierDescriptor as PolyPolygonBezierDescriptor
from ...dyn.drawing.poly_polygon_bezier_shape import PolyPolygonBezierShape as PolyPolygonBezierShape
from ...dyn.drawing.poly_polygon_descriptor import PolyPolygonDescriptor as PolyPolygonDescriptor
from ...dyn.drawing.poly_polygon_shape import PolyPolygonShape as PolyPolygonShape
from ...dyn.drawing.poly_polygon_shape3_d import PolyPolygonShape3D as PolyPolygonShape3D
from ...dyn.drawing.polygon_flags import PolygonFlags as PolygonFlags
from ...dyn.drawing.polygon_kind import PolygonKind as PolygonKind
from ...dyn.drawing.position3_d import Position3D as Position3D
from ...dyn.drawing.projection_mode import ProjectionMode as ProjectionMode
from ...dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
from ...dyn.drawing.rectangle_shape import RectangleShape as RectangleShape
from ...dyn.drawing.rotation_descriptor import RotationDescriptor as RotationDescriptor
from ...dyn.drawing.shade_mode import ShadeMode as ShadeMode
from ...dyn.drawing.shading_pattern import ShadingPattern as ShadingPattern
from ...dyn.drawing.shading_pattern import ShadingPatternEnum as ShadingPatternEnum
from ...dyn.drawing.shadow_properties import ShadowProperties as ShadowProperties
from ...dyn.drawing.shape import Shape as Shape
from ...dyn.drawing.shape_collection import ShapeCollection as ShapeCollection
from ...dyn.drawing.shapes import Shapes as Shapes
from ...dyn.drawing.slide_renderer import SlideRenderer as SlideRenderer
from ...dyn.drawing.slide_sorter import SlideSorter as SlideSorter
from ...dyn.drawing.snap_object_type import SnapObjectType as SnapObjectType
from ...dyn.drawing.text import Text as Text
from ...dyn.drawing.text_adjust import TextAdjust as TextAdjust
from ...dyn.drawing.text_animation_direction import TextAnimationDirection as TextAnimationDirection
from ...dyn.drawing.text_animation_kind import TextAnimationKind as TextAnimationKind
from ...dyn.drawing.text_fit_to_size_type import TextFitToSizeType as TextFitToSizeType
from ...dyn.drawing.text_horizontal_adjust import TextHorizontalAdjust as TextHorizontalAdjust
from ...dyn.drawing.text_properties import TextProperties as TextProperties
from ...dyn.drawing.text_shape import TextShape as TextShape
from ...dyn.drawing.text_vertical_adjust import TextVerticalAdjust as TextVerticalAdjust
from ...dyn.drawing.texture_kind import TextureKind as TextureKind
from ...dyn.drawing.texture_kind2 import TextureKind2 as TextureKind2
from ...dyn.drawing.texture_mode import TextureMode as TextureMode
from ...dyn.drawing.texture_projection_mode import TextureProjectionMode as TextureProjectionMode
from ...dyn.drawing.transparency_gradient_table import TransparencyGradientTable as TransparencyGradientTable
from ...dyn.drawing.vertical_dimensioning import VerticalDimensioning as VerticalDimensioning
from ...dyn.drawing.x_connectable_shape import XConnectableShape as XConnectableShape
from ...dyn.drawing.x_connector_shape import XConnectorShape as XConnectorShape
from ...dyn.drawing.x_control_shape import XControlShape as XControlShape
from ...dyn.drawing.x_custom_shape_engine import XCustomShapeEngine as XCustomShapeEngine
from ...dyn.drawing.x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle
from ...dyn.drawing.x_draw_page import XDrawPage as XDrawPage
from ...dyn.drawing.x_draw_page_duplicator import XDrawPageDuplicator as XDrawPageDuplicator
from ...dyn.drawing.x_draw_page_expander import XDrawPageExpander as XDrawPageExpander
from ...dyn.drawing.x_draw_page_summarizer import XDrawPageSummarizer as XDrawPageSummarizer
from ...dyn.drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier
from ...dyn.drawing.x_draw_pages import XDrawPages as XDrawPages
from ...dyn.drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier
from ...dyn.drawing.x_draw_sub_controller import XDrawSubController as XDrawSubController
from ...dyn.drawing.x_draw_view import XDrawView as XDrawView
from ...dyn.drawing.x_enhanced_custom_shape_defaulter import XEnhancedCustomShapeDefaulter as XEnhancedCustomShapeDefaulter
from ...dyn.drawing.x_glue_points_supplier import XGluePointsSupplier as XGluePointsSupplier
from ...dyn.drawing.x_graphic_export_filter import XGraphicExportFilter as XGraphicExportFilter
from ...dyn.drawing.x_layer import XLayer as XLayer
from ...dyn.drawing.x_layer_manager import XLayerManager as XLayerManager
from ...dyn.drawing.x_layer_supplier import XLayerSupplier as XLayerSupplier
from ...dyn.drawing.x_master_page_target import XMasterPageTarget as XMasterPageTarget
from ...dyn.drawing.x_master_pages_supplier import XMasterPagesSupplier as XMasterPagesSupplier
from ...dyn.drawing.x_presenter_helper import XPresenterHelper as XPresenterHelper
from ...dyn.drawing.x_selection_function import XSelectionFunction as XSelectionFunction
from ...dyn.drawing.x_shape import XShape as XShape
from ...dyn.drawing.x_shape_aligner import XShapeAligner as XShapeAligner
from ...dyn.drawing.x_shape_arranger import XShapeArranger as XShapeArranger
from ...dyn.drawing.x_shape_binder import XShapeBinder as XShapeBinder
from ...dyn.drawing.x_shape_combiner import XShapeCombiner as XShapeCombiner
from ...dyn.drawing.x_shape_descriptor import XShapeDescriptor as XShapeDescriptor
from ...dyn.drawing.x_shape_group import XShapeGroup as XShapeGroup
from ...dyn.drawing.x_shape_grouper import XShapeGrouper as XShapeGrouper
from ...dyn.drawing.x_shape_mirror import XShapeMirror as XShapeMirror
from ...dyn.drawing.x_shapes import XShapes as XShapes
from ...dyn.drawing.x_shapes2 import XShapes2 as XShapes2
from ...dyn.drawing.x_shapes3 import XShapes3 as XShapes3
from ...dyn.drawing.x_slide_preview_cache import XSlidePreviewCache as XSlidePreviewCache
from ...dyn.drawing.x_slide_preview_cache_listener import XSlidePreviewCacheListener as XSlidePreviewCacheListener
from ...dyn.drawing.x_slide_renderer import XSlideRenderer as XSlideRenderer
from ...dyn.drawing.x_slide_sorter_base import XSlideSorterBase as XSlideSorterBase
from ...dyn.drawing.x_universal_shape_descriptor import XUniversalShapeDescriptor as XUniversalShapeDescriptor



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from .poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords_7ec5114b
    from .x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle_2a620f04
    from .x_shape import XShape as XShape_8fd00a3d

class XCustomShapeEngine(XInterface_8f010a43):
    """
    The XCustomShapeEngine.

    See Also:
        `API XCustomShapeEngine <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XCustomShapeEngine.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XCustomShapeEngine'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XCustomShapeEngine'

    @abstractmethod
    def getInteraction(self) -> 'typing.Tuple[XCustomShapeHandle_2a620f04, ...]':
        """
        """
    @abstractmethod
    def getLineGeometry(self) -> 'PolyPolygonBezierCoords_7ec5114b':
        """
        """
    @abstractmethod
    def getTextBounds(self) -> 'Rectangle_84b109e9':
        """
        """
    @abstractmethod
    def render(self) -> 'XShape_8fd00a3d':
        """
        """

__all__ = ['XCustomShapeEngine']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XAlterTable(XInterface_8f010a43):
    """
    is used for creating and appending new objects to a specific container.

    See Also:
        `API XAlterTable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XAlterTable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.XAlterTable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbcx.XAlterTable'

    @abstractmethod
    def alterColumnByIndex(self, index: int, descriptor: 'XPropertySet_bc180bfa') -> None:
        """
        is intended to alter an existing column identified by its position.
        
        This operation must be atomic, in that it is done in one step.s

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    @abstractmethod
    def alterColumnByName(self, colName: str, descriptor: 'XPropertySet_bc180bfa') -> None:
        """
        is intended to alter an existing column identified by its name.
        
        This operation must be atomic, in that it is done in one step.s

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """

__all__ = ['XAlterTable']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb.application
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdb.application import DatabaseObject as DatabaseObject
    if hasattr(DatabaseObject, '_constants') and isinstance(DatabaseObject._constants, dict):
        DatabaseObject._constants['__ooo_ns__'] = 'com.sun.star.sdb.application'
        DatabaseObject._constants['__ooo_full_ns__'] = 'com.sun.star.sdb.application.DatabaseObject'
        DatabaseObject._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global DatabaseObjectEnum
        ls = [f for f in dir(DatabaseObject) if not callable(getattr(DatabaseObject, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(DatabaseObject, name)
        DatabaseObjectEnum = IntEnum('DatabaseObjectEnum', _dict)
    build_enum()
else:
    from ....lo.sdb.application.database_object import DatabaseObject as DatabaseObject

    class DatabaseObjectEnum(IntEnum):
        """
        Enum of Const Class DatabaseObject

        denotes different objects within a database document
        
        **since**
        
            OOo 2.2
        """
        TABLE = DatabaseObject.TABLE
        """
        denotes a table in a database
        
        Note that table here is a more general term. In OpenOffice.org Base, views are also represented as tables, since to the user, the behave pretty much as tables do.
        """
        QUERY = DatabaseObject.QUERY
        """
        denotes a query in a database document
        """
        FORM = DatabaseObject.FORM
        """
        denotes a form in a database document
        """
        REPORT = DatabaseObject.REPORT
        """
        denotes a report in a database document
        """

__all__ = ['DatabaseObject', 'DatabaseObjectEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from .x_frame import XFrame as XFrame_7a570956

class XFrames(XIndexAccess_f0910d6d):
    """
    manages and creates frames.
    
    Frames may contain other frames (by implementing an XFrames interface) and may be contained in other frames.

    See Also:
        `API XFrames <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XFrames.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XFrames'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XFrames'

    @abstractmethod
    def append(self, xFrame: 'XFrame_7a570956') -> None:
        """
        appends the specified Frame to the list of sub-frames.
        """
    @abstractmethod
    def queryFrames(self, nSearchFlags: int) -> 'typing.Tuple[XFrame_7a570956, ...]':
        """
        provides access to the list of all currently existing frames inside this container and her sub frames
        """
    @abstractmethod
    def remove(self, xFrame: 'XFrame_7a570956') -> None:
        """
        removes the frame from its container.
        
        Note:
        """

__all__ = ['XFrames']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .rows_change_event import RowsChangeEvent as RowsChangeEvent_c6e90c34

class XRowsChangeListener(XEventListener_c7230c4a):
    """
    is used for receiving \"rowsChanged\" events posted by, for example, a row set.

    See Also:
        `API XRowsChangeListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XRowsChangeListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XRowsChangeListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XRowsChangeListener'

    @abstractmethod
    def rowsChanged(self, event: 'RowsChangeEvent_c6e90c34') -> None:
        """
        is called when rows are inserted, updated, or deleted.
        """

__all__ = ['XRowsChangeListener']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_active_data_source import XActiveDataSource as XActiveDataSource_d1900c7f
    from .x_data_transfer_event_listener import XDataTransferEventListener as XDataTransferEventListener_54d6103f
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XDataImporter(XInterface_8f010a43):
    """
    makes it possible to import data from a data source into a component.
    
    Importer objects are registered for specific components and data types.

    See Also:
        `API XDataImporter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XDataImporter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XDataImporter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XDataImporter'

    @abstractmethod
    def cancel(self) -> None:
        """
        cancels the import process.
        """
    @abstractmethod
    def importData(self, aActiveSource: 'XActiveDataSource_d1900c7f', Component: 'XComponent_98dc0ab5', aListener: 'XDataTransferEventListener_54d6103f') -> None:
        """
        imports data for a component from an active data source.
        """

__all__ = ['XDataImporter']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbcx import CompareBookmark as CompareBookmark
    if hasattr(CompareBookmark, '_constants') and isinstance(CompareBookmark._constants, dict):
        CompareBookmark._constants['__ooo_ns__'] = 'com.sun.star.sdbcx'
        CompareBookmark._constants['__ooo_full_ns__'] = 'com.sun.star.sdbcx.CompareBookmark'
        CompareBookmark._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global CompareBookmarkEnum
        ls = [f for f in dir(CompareBookmark) if not callable(getattr(CompareBookmark, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(CompareBookmark, name)
        CompareBookmarkEnum = IntEnum('CompareBookmarkEnum', _dict)
    build_enum()
else:
    from ...lo.sdbcx.compare_bookmark import CompareBookmark as CompareBookmark

    class CompareBookmarkEnum(IntEnum):
        """
        Enum of Const Class CompareBookmark

        describes the result of a comparison of two bookmarks.
        """
        LESS = CompareBookmark.LESS
        """
        the first bookmark is before the second.
        """
        EQUAL = CompareBookmark.EQUAL
        """
        the first bookmark is equal to the second.
        """
        GREATER = CompareBookmark.GREATER
        """
        the first bookmark is after the second one.
        """
        NOT_EQUAL = CompareBookmark.NOT_EQUAL
        """
        the first bookmark is not the same as the second one.
        """
        NOT_COMPARABLE = CompareBookmark.NOT_COMPARABLE
        """
        the two bookmarks are not comparable.
        """

__all__ = ['CompareBookmark', 'CompareBookmarkEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.view
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XLineCursor(XInterface_8f010a43):
    """
    makes it possible to move a cursor by lines within laid out text.

    See Also:
        `API XLineCursor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XLineCursor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XLineCursor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XLineCursor'

    @abstractmethod
    def gotoEndOfLine(self, bExpand: bool) -> None:
        """
        moves the cursor to the end of the current line.
        """
    @abstractmethod
    def gotoStartOfLine(self, bExpand: bool) -> None:
        """
        moves the cursor to the start of the current line.
        """
    @abstractmethod
    def isAtEndOfLine(self) -> bool:
        """
        determines if the cursor is positioned at the end of a line.
        """
    @abstractmethod
    def isAtStartOfLine(self) -> bool:
        """
        determines if the cursor is positioned at the start of a line.
        """

__all__ = ['XLineCursor']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4

class Defaults(CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, ParagraphPropertiesAsian_6e8c10e8, ParagraphPropertiesComplex_91de11d4, XPropertySet_bc180bfa):
    """
    Service Class

    provides default settings of a text component for paragraph and character properties.

    See Also:
        `API Defaults <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1Defaults.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.Defaults'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def TabStopDistance(self) -> int:
        """
        default tab-distance to be used.
        """



__all__ = ['Defaults']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.document
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_document_properties import XDocumentProperties as XDocumentProperties_4c31102b

class XDocumentPropertiesSupplier(ABC):
    """
    provides access to the XDocumentProperties instance of a document.
    
    A DocumentProperties instance is available on loaded documents via this supplier interface.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XDocumentPropertiesSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentPropertiesSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XDocumentPropertiesSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XDocumentPropertiesSupplier'

    @abstractmethod
    def getDocumentProperties(self) -> 'XDocumentProperties_4c31102b':
        """
        provides the document properties object.
        """

__all__ = ['XDocumentPropertiesSupplier']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.ui.dialogs import ExecutableDialogResults as ExecutableDialogResults
    if hasattr(ExecutableDialogResults, '_constants') and isinstance(ExecutableDialogResults._constants, dict):
        ExecutableDialogResults._constants['__ooo_ns__'] = 'com.sun.star.ui.dialogs'
        ExecutableDialogResults._constants['__ooo_full_ns__'] = 'com.sun.star.ui.dialogs.ExecutableDialogResults'
        ExecutableDialogResults._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ExecutableDialogResultsEnum
        ls = [f for f in dir(ExecutableDialogResults) if not callable(getattr(ExecutableDialogResults, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ExecutableDialogResults, name)
        ExecutableDialogResultsEnum = IntEnum('ExecutableDialogResultsEnum', _dict)
    build_enum()
else:
    from ....lo.ui.dialogs.executable_dialog_results import ExecutableDialogResults as ExecutableDialogResults

    class ExecutableDialogResultsEnum(IntEnum):
        """
        Enum of Const Class ExecutableDialogResults

        These constants are used to specify a result of executing a XExecutableDialog.
        """
        CANCEL = ExecutableDialogResults.CANCEL
        """
        The user canceled the dialog.
        """
        OK = ExecutableDialogResults.OK
        """
        The user acknowledged the dialog.
        """

__all__ = ['ExecutableDialogResults', 'ExecutableDialogResultsEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
import typing
from abc import abstractmethod
from .x_idl_member import XIdlMember as XIdlMember_e3400cfc
if typing.TYPE_CHECKING:
    from .method_mode import MethodMode as MethodMode_e4910d19
    from .param_info import ParamInfo as ParamInfo_d7210cb0
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a

class XIdlMethod(XIdlMember_e3400cfc):
    """
    Reflects an IDL interface method.

    See Also:
        `API XIdlMethod <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlMethod'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlMethod'

    @abstractmethod
    def getExceptionTypes(self) -> 'typing.Tuple[XIdlClass_d63a0c9a, ...]':
        """
        Returns the declared exceptions types of the reflected method.
        """
    @abstractmethod
    def getMode(self) -> 'MethodMode_e4910d19':
        """
        Returns the method mode in which calls are run, i.e.
        
        either oneway or twoway. Method mode oneway denotes that a call may be run asynchronously (thus having no out parameters or return value)
        """
    @abstractmethod
    def getParameterInfos(self) -> 'typing.Tuple[ParamInfo_d7210cb0, ...]':
        """
        Returns formal parameter information of the reflected method in order of IDL declaration.
        
        Parameter information reflects the parameter's access mode (in, out, inout), the parameter's name and formal type.
        """
    @abstractmethod
    def getParameterTypes(self) -> 'typing.Tuple[XIdlClass_d63a0c9a, ...]':
        """
        Returns the formal parameter types of the reflected method in order of IDL declaration.
        """
    @abstractmethod
    def getReturnType(self) -> 'XIdlClass_d63a0c9a':
        """
        Returns the return type of the reflected method.
        """
    @abstractmethod
    def invoke(self, obj: object, args: object) -> object:
        """
        Invokes the reflected method on a given object with the given parameters.
        
        The parameters may be widening converted to fit their exact IDL type, meaning no loss of information.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """

__all__ = ['XIdlMethod']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.linguistic2 import SpellFailure as SpellFailure
    if hasattr(SpellFailure, '_constants') and isinstance(SpellFailure._constants, dict):
        SpellFailure._constants['__ooo_ns__'] = 'com.sun.star.linguistic2'
        SpellFailure._constants['__ooo_full_ns__'] = 'com.sun.star.linguistic2.SpellFailure'
        SpellFailure._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global SpellFailureEnum
        ls = [f for f in dir(SpellFailure) if not callable(getattr(SpellFailure, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(SpellFailure, name)
        SpellFailureEnum = IntEnum('SpellFailureEnum', _dict)
    build_enum()
else:
    from ...lo.linguistic2.spell_failure import SpellFailure as SpellFailure

    class SpellFailureEnum(IntEnum):
        """
        Enum of Const Class SpellFailure

        these define the various return types for spell checking to fail verification.
        
        A value of this type is part of the com.sun.star.linguistic2.XSpellAlternatives interface which is the return type for an unsuccessful spelling attempt.
        """
        IS_NEGATIVE_WORD = SpellFailure.IS_NEGATIVE_WORD
        """
        The word is a negative one, that is, it should not be used.
        """
        CAPTION_ERROR = SpellFailure.CAPTION_ERROR
        """
        The capitalization of the word is wrong.
        """
        SPELLING_ERROR = SpellFailure.SPELLING_ERROR
        """
        The spelling of the word is wrong (or at least not known to be correct).
        """

__all__ = ['SpellFailure', 'SpellFailureEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.awt import FontStrikeout as FontStrikeout
    if hasattr(FontStrikeout, '_constants') and isinstance(FontStrikeout._constants, dict):
        FontStrikeout._constants['__ooo_ns__'] = 'com.sun.star.awt'
        FontStrikeout._constants['__ooo_full_ns__'] = 'com.sun.star.awt.FontStrikeout'
        FontStrikeout._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global FontStrikeoutEnum
        ls = [f for f in dir(FontStrikeout) if not callable(getattr(FontStrikeout, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(FontStrikeout, name)
        FontStrikeoutEnum = IntEnum('FontStrikeoutEnum', _dict)
    build_enum()
else:
    from ...lo.awt.font_strikeout import FontStrikeout as FontStrikeout

    class FontStrikeoutEnum(IntEnum):
        """
        Enum of Const Class FontStrikeout

        These values are used to specify the kind of strikeout.
        
        They may be expanded in future versions.
        """
        NONE = FontStrikeout.NONE
        """
        specifies not to strike out the characters.
        """
        SINGLE = FontStrikeout.SINGLE
        """
        specifies to strike out the characters with a single line.
        """
        DOUBLE = FontStrikeout.DOUBLE
        """
        specifies to strike out the characters with a double line.
        """
        DONTKNOW = FontStrikeout.DONTKNOW
        """
        The strikeout mode is not specified.
        """
        BOLD = FontStrikeout.BOLD
        """
        specifies to strike out the characters with a bold line.
        """
        SLASH = FontStrikeout.SLASH
        """
        specifies to strike out the characters with slashes.
        """
        X = FontStrikeout.X
        """
        specifies to strike out the characters with X's.
        """

__all__ = ['FontStrikeout', 'FontStrikeoutEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.style import ParagraphStyleCategory as ParagraphStyleCategory
    if hasattr(ParagraphStyleCategory, '_constants') and isinstance(ParagraphStyleCategory._constants, dict):
        ParagraphStyleCategory._constants['__ooo_ns__'] = 'com.sun.star.style'
        ParagraphStyleCategory._constants['__ooo_full_ns__'] = 'com.sun.star.style.ParagraphStyleCategory'
        ParagraphStyleCategory._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ParagraphStyleCategoryEnum
        ls = [f for f in dir(ParagraphStyleCategory) if not callable(getattr(ParagraphStyleCategory, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ParagraphStyleCategory, name)
        ParagraphStyleCategoryEnum = IntEnum('ParagraphStyleCategoryEnum', _dict)
    build_enum()
else:
    from ...lo.style.paragraph_style_category import ParagraphStyleCategory as ParagraphStyleCategory

    class ParagraphStyleCategoryEnum(IntEnum):
        """
        Enum of Const Class ParagraphStyleCategory

        These constants are used to specify the category of paragraph styles in text documents.
        """
        TEXT = ParagraphStyleCategory.TEXT
        """
        is applied to styles that are used for common text.
        """
        CHAPTER = ParagraphStyleCategory.CHAPTER
        """
        is applied to styles that are used as headings.
        """
        LIST = ParagraphStyleCategory.LIST
        """
        is applied to styles that used in numberings and lists.
        """
        INDEX = ParagraphStyleCategory.INDEX
        """
        is applied to styles that are used in indexes.
        """
        EXTRA = ParagraphStyleCategory.EXTRA
        """
        is applied to styles that are used in special regions like headers, footers, and footnote text.
        """
        HTML = ParagraphStyleCategory.HTML
        """
        is applied to styles that are used to support HTML.
        """

__all__ = ['ParagraphStyleCategory', 'ParagraphStyleCategoryEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.3
from enum import Enum


class ClickAction(Enum):
    """
    Enum Class

    

    See Also:
        `API ClickAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8f>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.ClickAction'
    __ooo_type_name__: str = 'enum'

    BOOKMARK = 'BOOKMARK'
    """
    The presentation jumps to a bookmark.
    """
    DOCUMENT = 'DOCUMENT'
    """
    The presentation jumps to another document.
    """
    FIRSTPAGE = 'FIRSTPAGE'
    """
    The presentation continues with the first page.
    """
    INVISIBLE = 'INVISIBLE'
    """
    The object renders itself invisible after a click.
    """
    LASTPAGE = 'LASTPAGE'
    """
    The presentation continues with the last page.
    """
    MACRO = 'MACRO'
    """
    A star basic macro is executed after the click.
    """
    NEXTPAGE = 'NEXTPAGE'
    """
    The presentation jumps to the next page.
    """
    NONE = 'NONE'
    """
    use no animation effects.
    
    use no fade effects.
    
    No action is performed on click.
    """
    PREVPAGE = 'PREVPAGE'
    """
    The presentation jumps to the previous page.
    """
    PROGRAM = 'PROGRAM'
    """
    Another program is executed after a click.
    """
    SOUND = 'SOUND'
    """
    A sound is played after a click.
    """
    STOPPRESENTATION = 'STOPPRESENTATION'
    """
    The presentation is stopped after the click.
    """
    VANISH = 'VANISH'
    """
    The object vanishes with its effect.
    """
    VERB = 'VERB'
    """
    An OLE verb is performed on this object.
    """

__all__ = ['ClickAction']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
import typing
from abc import abstractproperty
from ..chart.x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from .sheet_ranges_query import SheetRangesQuery as SheetRangesQuery_efbe0d90
from .x_sheet_cell_range_container import XSheetCellRangeContainer as XSheetCellRangeContainer_661f1082
from .x_sheet_operation import XSheetOperation as XSheetOperation_e1f50d23
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..table.cell_properties import CellProperties as CellProperties_d4360cbd
from ..util.x_indent import XIndent as XIndent_7b290980
from ..util.x_replaceable import XReplaceable as XReplaceable_b0750b6e
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries_694810c0

class SheetCellRanges(SheetRangesQuery_efbe0d90, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, CellProperties_d4360cbd, XChartDataArray_df4c0cdd, XEnumerationAccess_4bac0ffc, XNameContainer_cb90e47, XSheetCellRangeContainer_661f1082, XSheetOperation_e1f50d23, XIndent_7b290980, XReplaceable_b0750b6e):
    """
    Service Class

    represents a collection of cell ranges in a spreadsheet document.

    See Also:
        `API SheetCellRanges <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRanges.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SheetCellRanges'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AbsoluteName(self) -> str:
        """
        Returns the absolute address of the ranges as string, e.g.
        
        \"$Sheet1.$B$2:$D$5\".
        """

    @abstractproperty
    def ConditionalFormat(self) -> 'XSheetConditionalEntries_694810c0':
        """
        contains the conditional formatting settings for this cell.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """

    @abstractproperty
    def ConditionalFormatLocal(self) -> 'XSheetConditionalEntries_694810c0':
        """
        contains the conditional formatting settings for this cell, using localized formulas.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """

    @abstractproperty
    def Validation(self) -> 'XPropertySet_bc180bfa':
        """
        contains the data validation settings for this cell.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """

    @abstractproperty
    def ValidationLocal(self) -> 'XPropertySet_bc180bfa':
        """
        contains the data validation settings for this cell, using localized formulas.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """



__all__ = ['SheetCellRanges']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sheet import DataPilotFieldSortMode as DataPilotFieldSortMode
    if hasattr(DataPilotFieldSortMode, '_constants') and isinstance(DataPilotFieldSortMode._constants, dict):
        DataPilotFieldSortMode._constants['__ooo_ns__'] = 'com.sun.star.sheet'
        DataPilotFieldSortMode._constants['__ooo_full_ns__'] = 'com.sun.star.sheet.DataPilotFieldSortMode'
        DataPilotFieldSortMode._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global DataPilotFieldSortModeEnum
        ls = [f for f in dir(DataPilotFieldSortMode) if not callable(getattr(DataPilotFieldSortMode, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(DataPilotFieldSortMode, name)
        DataPilotFieldSortModeEnum = IntEnum('DataPilotFieldSortModeEnum', _dict)
    build_enum()
else:
    from ...lo.sheet.data_pilot_field_sort_mode import DataPilotFieldSortMode as DataPilotFieldSortMode

    class DataPilotFieldSortModeEnum(IntEnum):
        """
        Enum of Const Class DataPilotFieldSortMode

        describes the sort mode of the data field
        """
        NONE = DataPilotFieldSortMode.NONE
        """
        the data are taken as they come from the DataPilotSource.
        """
        MANUAL = DataPilotFieldSortMode.MANUAL
        """
        the user can sort the fields
        """
        NAME = DataPilotFieldSortMode.NAME
        """
        the field is sorted by its names
        """
        DATA = DataPilotFieldSortMode.DATA
        """
        the field is sorted by the data in the given field
        """

__all__ = ['DataPilotFieldSortMode', 'DataPilotFieldSortModeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.ucb.IOErrorCode import (ABORT, ACCESS_DENIED, ALREADY_EXISTING, BAD_CRC, CANT_CREATE, CANT_READ, CANT_SEEK, CANT_TELL, CANT_WRITE, CURRENT_DIRECTORY, DEVICE_NOT_READY, DIFFERENT_DEVICES, GENERAL, INVALID_ACCESS, INVALID_CHARACTER, INVALID_DEVICE, INVALID_LENGTH, INVALID_PARAMETER, IS_WILDCARD, LOCKING_VIOLATION, MISPLACED_CHARACTER, NAME_TOO_LONG, NOT_EXISTING, NOT_EXISTING_PATH, NOT_SUPPORTED, NO_DIRECTORY, NO_FILE, OUT_OF_DISK_SPACE, OUT_OF_FILE_HANDLES, OUT_OF_MEMORY, PENDING, RECURSIVE, UNKNOWN, WRITE_PROTECTED, WRONG_FORMAT, WRONG_VERSION)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.ucb.IOErrorCode Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.ucb",
            "__ooo_full_ns__": "com.sun.star.ucb.IOErrorCode",
            "__ooo_type_name__": "enum",
            "ABORT": ABORT,
            "ACCESS_DENIED": ACCESS_DENIED,
            "ALREADY_EXISTING": ALREADY_EXISTING,
            "BAD_CRC": BAD_CRC,
            "CANT_CREATE": CANT_CREATE,
            "CANT_READ": CANT_READ,
            "CANT_SEEK": CANT_SEEK,
            "CANT_TELL": CANT_TELL,
            "CANT_WRITE": CANT_WRITE,
            "CURRENT_DIRECTORY": CURRENT_DIRECTORY,
            "DEVICE_NOT_READY": DEVICE_NOT_READY,
            "DIFFERENT_DEVICES": DIFFERENT_DEVICES,
            "GENERAL": GENERAL,
            "INVALID_ACCESS": INVALID_ACCESS,
            "INVALID_CHARACTER": INVALID_CHARACTER,
            "INVALID_DEVICE": INVALID_DEVICE,
            "INVALID_LENGTH": INVALID_LENGTH,
            "INVALID_PARAMETER": INVALID_PARAMETER,
            "IS_WILDCARD": IS_WILDCARD,
            "LOCKING_VIOLATION": LOCKING_VIOLATION,
            "MISPLACED_CHARACTER": MISPLACED_CHARACTER,
            "NAME_TOO_LONG": NAME_TOO_LONG,
            "NOT_EXISTING": NOT_EXISTING,
            "NOT_EXISTING_PATH": NOT_EXISTING_PATH,
            "NOT_SUPPORTED": NOT_SUPPORTED,
            "NO_DIRECTORY": NO_DIRECTORY,
            "NO_FILE": NO_FILE,
            "OUT_OF_DISK_SPACE": OUT_OF_DISK_SPACE,
            "OUT_OF_FILE_HANDLES": OUT_OF_FILE_HANDLES,
            "OUT_OF_MEMORY": OUT_OF_MEMORY,
            "PENDING": PENDING,
            "RECURSIVE": RECURSIVE,
            "UNKNOWN": UNKNOWN,
            "WRITE_PROTECTED": WRITE_PROTECTED,
            "WRONG_FORMAT": WRONG_FORMAT,
            "WRONG_VERSION": WRONG_VERSION,
        }
        result = type('IOErrorCode', (object,), _dict)
        return result

    IOErrorCode = _get_enum()
else:
    from ...lo.ucb.io_error_code import IOErrorCode as IOErrorCode

__all__ = ['IOErrorCode']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering


class PathCapType(object):
    """
    Const Class

    These constants determine which shape to use for start or end of a stroked path.
    
    The start and end of stroked paths can have one out of several different shapes (which are, of course, only visible for strokes wider than one device pixel).
    
    **since**
    
        OOo 2.0

    See Also:
        `API PathCapType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1PathCapType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.PathCapType'
    __ooo_type_name__: str = 'const'

    BUTT = 0
    """
    End the path at its start or end point, without any cap.
    """
    ROUND = 1
    """
    Extend the path with a half circle cap, diameter is the line width.
    """
    SQUARE = 2
    """
    Extend the path with a rectangular cap, half the line width long.
    """

__all__ = ['PathCapType']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.xpath
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.xml.xpath.XPathObjectType import (XPATH_BOOLEAN, XPATH_LOCATIONSET, XPATH_NODESET, XPATH_NUMBER, XPATH_POINT, XPATH_RANGE, XPATH_STRING, XPATH_UNDEFINED, XPATH_USERS, XPATH_XSLT_TREE)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.xml.xpath.XPathObjectType Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.xml.xpath",
            "__ooo_full_ns__": "com.sun.star.xml.xpath.XPathObjectType",
            "__ooo_type_name__": "enum",
            "XPATH_BOOLEAN": XPATH_BOOLEAN,
            "XPATH_LOCATIONSET": XPATH_LOCATIONSET,
            "XPATH_NODESET": XPATH_NODESET,
            "XPATH_NUMBER": XPATH_NUMBER,
            "XPATH_POINT": XPATH_POINT,
            "XPATH_RANGE": XPATH_RANGE,
            "XPATH_STRING": XPATH_STRING,
            "XPATH_UNDEFINED": XPATH_UNDEFINED,
            "XPATH_USERS": XPATH_USERS,
            "XPATH_XSLT_TREE": XPATH_XSLT_TREE,
        }
        result = type('XPathObjectType', (object,), _dict)
        return result

    XPathObjectType = _get_enum()
else:
    from ....lo.xml.xpath.x_path_object_type import XPathObjectType as XPathObjectType

__all__ = ['XPathObjectType']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.rendering import PanoseLetterForm as PanoseLetterForm
    if hasattr(PanoseLetterForm, '_constants') and isinstance(PanoseLetterForm._constants, dict):
        PanoseLetterForm._constants['__ooo_ns__'] = 'com.sun.star.rendering'
        PanoseLetterForm._constants['__ooo_full_ns__'] = 'com.sun.star.rendering.PanoseLetterForm'
        PanoseLetterForm._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global PanoseLetterFormEnum
        ls = [f for f in dir(PanoseLetterForm) if not callable(getattr(PanoseLetterForm, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(PanoseLetterForm, name)
        PanoseLetterFormEnum = IntEnum('PanoseLetterFormEnum', _dict)
    build_enum()
else:
    from ...lo.rendering.panose_letter_form import PanoseLetterForm as PanoseLetterForm

    class PanoseLetterFormEnum(IntEnum):
        """
        Enum of Const Class PanoseLetterForm

        """
        ANYTHING = PanoseLetterForm.ANYTHING
        NO_FIT = PanoseLetterForm.NO_FIT
        NORMAL_CONTACT = PanoseLetterForm.NORMAL_CONTACT
        NORMAL_WEIGHTED = PanoseLetterForm.NORMAL_WEIGHTED
        NORMAL_BOXED = PanoseLetterForm.NORMAL_BOXED
        NORMAL_FLATTENED = PanoseLetterForm.NORMAL_FLATTENED
        NORMAL_ROUNDED = PanoseLetterForm.NORMAL_ROUNDED
        NORMAL_OFF_CENTER = PanoseLetterForm.NORMAL_OFF_CENTER
        NORMAL_SQUARE = PanoseLetterForm.NORMAL_SQUARE
        OBLIQUE_CONTACT = PanoseLetterForm.OBLIQUE_CONTACT
        OBLIQUE_WEIGHTED = PanoseLetterForm.OBLIQUE_WEIGHTED
        OBLIQUE_BOXED = PanoseLetterForm.OBLIQUE_BOXED
        OBLIQUE_FLATTENED = PanoseLetterForm.OBLIQUE_FLATTENED
        OBLIQUE_ROUNDED = PanoseLetterForm.OBLIQUE_ROUNDED
        OBLIQUE_OFF_CENTER = PanoseLetterForm.OBLIQUE_OFF_CENTER
        OBLIQUE_SQUARE = PanoseLetterForm.OBLIQUE_SQUARE

__all__ = ['PanoseLetterForm', 'PanoseLetterFormEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.i18n import Weekdays as Weekdays
    if hasattr(Weekdays, '_constants') and isinstance(Weekdays._constants, dict):
        Weekdays._constants['__ooo_ns__'] = 'com.sun.star.i18n'
        Weekdays._constants['__ooo_full_ns__'] = 'com.sun.star.i18n.Weekdays'
        Weekdays._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global WeekdaysEnum
        ls = [f for f in dir(Weekdays) if not callable(getattr(Weekdays, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(Weekdays, name)
        WeekdaysEnum = IntEnum('WeekdaysEnum', _dict)
    build_enum()
else:
    from ...lo.i18n.weekdays import Weekdays as Weekdays

    class WeekdaysEnum(IntEnum):
        """
        Enum of Const Class Weekdays

        Constants for days of a week.
        
        used with XCalendar.getFirstDayOfWeek(), XCalendar.setFirstDayOfWeek() and XCalendar.getDisplayName()
        """
        SUNDAY = Weekdays.SUNDAY
        """
        Sunday.
        """
        MONDAY = Weekdays.MONDAY
        """
        Monday.
        """
        TUESDAY = Weekdays.TUESDAY
        """
        Tuesday.
        """
        WEDNESDAY = Weekdays.WEDNESDAY
        """
        Wednesday.
        """
        THURSDAY = Weekdays.THURSDAY
        """
        Thursday.
        """
        FRIDAY = Weekdays.FRIDAY
        """
        Friday.
        """
        SATURDAY = Weekdays.SATURDAY
        """
        Saturday.
        """

__all__ = ['Weekdays', 'WeekdaysEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text.textfield
from abc import abstractproperty
from ..dependent_text_field import DependentTextField as DependentTextField_fed90ded

class DatabaseNumberOfSet(DependentTextField_fed90ded):
    """
    Service Class

    specifies service of text field that conditionally set the selection of a database cursor.
    
    Only one of the properties DataBaseName, DataBaseURL and DataBaseResource should be set. If more than one are set the last one will be used.
    
    **since**
    
        OOo 2.0

    See Also:
        `API DatabaseNumberOfSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseNumberOfSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.DatabaseNumberOfSet'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Condition(self) -> str:
        """
        contains the conditions that determines whether the SetNumber is applied or not.
        """

    @abstractproperty
    def DataBaseName(self) -> str:
        """
        specifies the database name.
        """

    @abstractproperty
    def DataBaseResource(self) -> str:
        """
        indicates a connection URL, which locates a database driver.
        
        **since**
        
            OOo 2.0
        """

    @abstractproperty
    def DataBaseURL(self) -> str:
        """
        indicates the URL of a database file.
        
        **since**
        
            OOo 2.0
        """

    @abstractproperty
    def DataCommandType(self) -> int:
        """
        determines the interpretation of the property DataTableName.
        """

    @abstractproperty
    def DataTableName(self) -> str:
        """
        contains the name of the database table, query or a statement depending on the DataCommandType property.
        """

    @abstractproperty
    def SetNumber(self) -> int:
        """
        contains the set number that is to be applied.
        """



__all__ = ['DatabaseNumberOfSet']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.awt import ImageDrawMode as ImageDrawMode
    if hasattr(ImageDrawMode, '_constants') and isinstance(ImageDrawMode._constants, dict):
        ImageDrawMode._constants['__ooo_ns__'] = 'com.sun.star.awt'
        ImageDrawMode._constants['__ooo_full_ns__'] = 'com.sun.star.awt.ImageDrawMode'
        ImageDrawMode._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ImageDrawModeEnum
        ls = [f for f in dir(ImageDrawMode) if not callable(getattr(ImageDrawMode, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ImageDrawMode, name)
        ImageDrawModeEnum = IntFlag('ImageDrawModeEnum', _dict)
    build_enum()
else:
    from ...lo.awt.image_draw_mode import ImageDrawMode as ImageDrawMode

    class ImageDrawModeEnum(IntFlag):
        """
        Enum of Const Class ImageDrawMode

        defines modes how an image is drawn onto a device
        
        **since**
        
            LibreOffice 4.1
        """
        NONE = ImageDrawMode.NONE
        """
        the image is drawn as is, without any color transformation.
        """
        DISABLE = ImageDrawMode.DISABLE
        """
        the image is drawn as if it represented a feature whose state is disabled.
        """
        HIGHLIGHT = ImageDrawMode.HIGHLIGHT
        """
        the image is drawn as being highlighted.
        
        See com.sun.star.awt.XStyleSettings.HighlightColor.
        """
        DEACTIVE = ImageDrawMode.DEACTIVE
        """
        the image is drawn as being deactivated.
        
        See com.sun.star.awt.XStyleSettings.DeactiveColor.
        """
        SEMITRANSPARENT = ImageDrawMode.SEMITRANSPARENT
        """
        the image is drawn semi-transparent.
        """

__all__ = ['ImageDrawMode', 'ImageDrawModeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.ucb import ConnectionMode as ConnectionMode
    if hasattr(ConnectionMode, '_constants') and isinstance(ConnectionMode._constants, dict):
        ConnectionMode._constants['__ooo_ns__'] = 'com.sun.star.ucb'
        ConnectionMode._constants['__ooo_full_ns__'] = 'com.sun.star.ucb.ConnectionMode'
        ConnectionMode._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ConnectionModeEnum
        ls = [f for f in dir(ConnectionMode) if not callable(getattr(ConnectionMode, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ConnectionMode, name)
        ConnectionModeEnum = IntEnum('ConnectionModeEnum', _dict)
    build_enum()
else:
    from ...lo.ucb.connection_mode import ConnectionMode as ConnectionMode

    class ConnectionModeEnum(IntEnum):
        """
        Enum of Const Class ConnectionMode

        These are the possible values for the property \"ConnectionMode\".
        """
        ONLINE = ConnectionMode.ONLINE
        """
        \"Online\" - Network access is allowed.
        """
        OFFLINE = ConnectionMode.OFFLINE
        """
        \"Offline\" - Network access is not allowed.
        """

__all__ = ['ConnectionMode', 'ConnectionModeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.presentation.AnimationEffect import (APPEAR, CLOCKWISE, CLOSE_HORIZONTAL, CLOSE_VERTICAL, COUNTERCLOCKWISE, DISSOLVE, FADE_FROM_BOTTOM, FADE_FROM_CENTER, FADE_FROM_LEFT, FADE_FROM_LOWERLEFT, FADE_FROM_LOWERRIGHT, FADE_FROM_RIGHT, FADE_FROM_TOP, FADE_FROM_UPPERLEFT, FADE_FROM_UPPERRIGHT, FADE_TO_CENTER, HIDE, HORIZONTAL_CHECKERBOARD, HORIZONTAL_LINES, HORIZONTAL_ROTATE, HORIZONTAL_STRETCH, HORIZONTAL_STRIPES, LASER_FROM_BOTTOM, LASER_FROM_LEFT, LASER_FROM_LOWERLEFT, LASER_FROM_LOWERRIGHT, LASER_FROM_RIGHT, LASER_FROM_TOP, LASER_FROM_UPPERLEFT, LASER_FROM_UPPERRIGHT, MOVE_FROM_BOTTOM, MOVE_FROM_LEFT, MOVE_FROM_LOWERLEFT, MOVE_FROM_LOWERRIGHT, MOVE_FROM_RIGHT, MOVE_FROM_TOP, MOVE_FROM_UPPERLEFT, MOVE_FROM_UPPERRIGHT, MOVE_SHORT_FROM_BOTTOM, MOVE_SHORT_FROM_LEFT, MOVE_SHORT_FROM_LOWERLEFT, MOVE_SHORT_FROM_LOWERRIGHT, MOVE_SHORT_FROM_RIGHT, MOVE_SHORT_FROM_TOP, MOVE_SHORT_FROM_UPPERLEFT, MOVE_SHORT_FROM_UPPERRIGHT, MOVE_SHORT_TO_BOTTOM, MOVE_SHORT_TO_LEFT, MOVE_SHORT_TO_LOWERLEFT, MOVE_SHORT_TO_LOWERRIGHT, MOVE_SHORT_TO_RIGHT, MOVE_SHORT_TO_TOP, MOVE_SHORT_TO_UPPERLEFT, MOVE_SHORT_TO_UPPERRIGHT, MOVE_TO_BOTTOM, MOVE_TO_LEFT, MOVE_TO_LOWERLEFT, MOVE_TO_LOWERRIGHT, MOVE_TO_RIGHT, MOVE_TO_TOP, MOVE_TO_UPPERLEFT, MOVE_TO_UPPERRIGHT, NONE, OPEN_HORIZONTAL, OPEN_VERTICAL, PATH, RANDOM, SPIRALIN_LEFT, SPIRALIN_RIGHT, SPIRALOUT_LEFT, SPIRALOUT_RIGHT, STRETCH_FROM_BOTTOM, STRETCH_FROM_LEFT, STRETCH_FROM_LOWERLEFT, STRETCH_FROM_LOWERRIGHT, STRETCH_FROM_RIGHT, STRETCH_FROM_TOP, STRETCH_FROM_UPPERLEFT, STRETCH_FROM_UPPERRIGHT, VERTICAL_CHECKERBOARD, VERTICAL_LINES, VERTICAL_ROTATE, VERTICAL_STRETCH, VERTICAL_STRIPES, WAVYLINE_FROM_BOTTOM, WAVYLINE_FROM_LEFT, WAVYLINE_FROM_RIGHT, WAVYLINE_FROM_TOP, ZOOM_IN, ZOOM_IN_FROM_BOTTOM, ZOOM_IN_FROM_CENTER, ZOOM_IN_FROM_LEFT, ZOOM_IN_FROM_LOWERLEFT, ZOOM_IN_FROM_LOWERRIGHT, ZOOM_IN_FROM_RIGHT, ZOOM_IN_FROM_TOP, ZOOM_IN_FROM_UPPERLEFT, ZOOM_IN_FROM_UPPERRIGHT, ZOOM_IN_SMALL, ZOOM_IN_SPIRAL, ZOOM_OUT, ZOOM_OUT_FROM_BOTTOM, ZOOM_OUT_FROM_CENTER, ZOOM_OUT_FROM_LEFT, ZOOM_OUT_FROM_LOWERLEFT, ZOOM_OUT_FROM_LOWERRIGHT, ZOOM_OUT_FROM_RIGHT, ZOOM_OUT_FROM_TOP, ZOOM_OUT_FROM_UPPERLEFT, ZOOM_OUT_FROM_UPPERRIGHT, ZOOM_OUT_SMALL, ZOOM_OUT_SPIRAL)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.presentation.AnimationEffect Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.presentation",
            "__ooo_full_ns__": "com.sun.star.presentation.AnimationEffect",
            "__ooo_type_name__": "enum",
            "APPEAR": APPEAR,
            "CLOCKWISE": CLOCKWISE,
            "CLOSE_HORIZONTAL": CLOSE_HORIZONTAL,
            "CLOSE_VERTICAL": CLOSE_VERTICAL,
            "COUNTERCLOCKWISE": COUNTERCLOCKWISE,
            "DISSOLVE": DISSOLVE,
            "FADE_FROM_BOTTOM": FADE_FROM_BOTTOM,
            "FADE_FROM_CENTER": FADE_FROM_CENTER,
            "FADE_FROM_LEFT": FADE_FROM_LEFT,
            "FADE_FROM_LOWERLEFT": FADE_FROM_LOWERLEFT,
            "FADE_FROM_LOWERRIGHT": FADE_FROM_LOWERRIGHT,
            "FADE_FROM_RIGHT": FADE_FROM_RIGHT,
            "FADE_FROM_TOP": FADE_FROM_TOP,
            "FADE_FROM_UPPERLEFT": FADE_FROM_UPPERLEFT,
            "FADE_FROM_UPPERRIGHT": FADE_FROM_UPPERRIGHT,
            "FADE_TO_CENTER": FADE_TO_CENTER,
            "HIDE": HIDE,
            "HORIZONTAL_CHECKERBOARD": HORIZONTAL_CHECKERBOARD,
            "HORIZONTAL_LINES": HORIZONTAL_LINES,
            "HORIZONTAL_ROTATE": HORIZONTAL_ROTATE,
            "HORIZONTAL_STRETCH": HORIZONTAL_STRETCH,
            "HORIZONTAL_STRIPES": HORIZONTAL_STRIPES,
            "LASER_FROM_BOTTOM": LASER_FROM_BOTTOM,
            "LASER_FROM_LEFT": LASER_FROM_LEFT,
            "LASER_FROM_LOWERLEFT": LASER_FROM_LOWERLEFT,
            "LASER_FROM_LOWERRIGHT": LASER_FROM_LOWERRIGHT,
            "LASER_FROM_RIGHT": LASER_FROM_RIGHT,
            "LASER_FROM_TOP": LASER_FROM_TOP,
            "LASER_FROM_UPPERLEFT": LASER_FROM_UPPERLEFT,
            "LASER_FROM_UPPERRIGHT": LASER_FROM_UPPERRIGHT,
            "MOVE_FROM_BOTTOM": MOVE_FROM_BOTTOM,
            "MOVE_FROM_LEFT": MOVE_FROM_LEFT,
            "MOVE_FROM_LOWERLEFT": MOVE_FROM_LOWERLEFT,
            "MOVE_FROM_LOWERRIGHT": MOVE_FROM_LOWERRIGHT,
            "MOVE_FROM_RIGHT": MOVE_FROM_RIGHT,
            "MOVE_FROM_TOP": MOVE_FROM_TOP,
            "MOVE_FROM_UPPERLEFT": MOVE_FROM_UPPERLEFT,
            "MOVE_FROM_UPPERRIGHT": MOVE_FROM_UPPERRIGHT,
            "MOVE_SHORT_FROM_BOTTOM": MOVE_SHORT_FROM_BOTTOM,
            "MOVE_SHORT_FROM_LEFT": MOVE_SHORT_FROM_LEFT,
            "MOVE_SHORT_FROM_LOWERLEFT": MOVE_SHORT_FROM_LOWERLEFT,
            "MOVE_SHORT_FROM_LOWERRIGHT": MOVE_SHORT_FROM_LOWERRIGHT,
            "MOVE_SHORT_FROM_RIGHT": MOVE_SHORT_FROM_RIGHT,
            "MOVE_SHORT_FROM_TOP": MOVE_SHORT_FROM_TOP,
            "MOVE_SHORT_FROM_UPPERLEFT": MOVE_SHORT_FROM_UPPERLEFT,
            "MOVE_SHORT_FROM_UPPERRIGHT": MOVE_SHORT_FROM_UPPERRIGHT,
            "MOVE_SHORT_TO_BOTTOM": MOVE_SHORT_TO_BOTTOM,
            "MOVE_SHORT_TO_LEFT": MOVE_SHORT_TO_LEFT,
            "MOVE_SHORT_TO_LOWERLEFT": MOVE_SHORT_TO_LOWERLEFT,
            "MOVE_SHORT_TO_LOWERRIGHT": MOVE_SHORT_TO_LOWERRIGHT,
            "MOVE_SHORT_TO_RIGHT": MOVE_SHORT_TO_RIGHT,
            "MOVE_SHORT_TO_TOP": MOVE_SHORT_TO_TOP,
            "MOVE_SHORT_TO_UPPERLEFT": MOVE_SHORT_TO_UPPERLEFT,
            "MOVE_SHORT_TO_UPPERRIGHT": MOVE_SHORT_TO_UPPERRIGHT,
            "MOVE_TO_BOTTOM": MOVE_TO_BOTTOM,
            "MOVE_TO_LEFT": MOVE_TO_LEFT,
            "MOVE_TO_LOWERLEFT": MOVE_TO_LOWERLEFT,
            "MOVE_TO_LOWERRIGHT": MOVE_TO_LOWERRIGHT,
            "MOVE_TO_RIGHT": MOVE_TO_RIGHT,
            "MOVE_TO_TOP": MOVE_TO_TOP,
            "MOVE_TO_UPPERLEFT": MOVE_TO_UPPERLEFT,
            "MOVE_TO_UPPERRIGHT": MOVE_TO_UPPERRIGHT,
            "NONE": NONE,
            "OPEN_HORIZONTAL": OPEN_HORIZONTAL,
            "OPEN_VERTICAL": OPEN_VERTICAL,
            "PATH": PATH,
            "RANDOM": RANDOM,
            "SPIRALIN_LEFT": SPIRALIN_LEFT,
            "SPIRALIN_RIGHT": SPIRALIN_RIGHT,
            "SPIRALOUT_LEFT": SPIRALOUT_LEFT,
            "SPIRALOUT_RIGHT": SPIRALOUT_RIGHT,
            "STRETCH_FROM_BOTTOM": STRETCH_FROM_BOTTOM,
            "STRETCH_FROM_LEFT": STRETCH_FROM_LEFT,
            "STRETCH_FROM_LOWERLEFT": STRETCH_FROM_LOWERLEFT,
            "STRETCH_FROM_LOWERRIGHT": STRETCH_FROM_LOWERRIGHT,
            "STRETCH_FROM_RIGHT": STRETCH_FROM_RIGHT,
            "STRETCH_FROM_TOP": STRETCH_FROM_TOP,
            "STRETCH_FROM_UPPERLEFT": STRETCH_FROM_UPPERLEFT,
            "STRETCH_FROM_UPPERRIGHT": STRETCH_FROM_UPPERRIGHT,
            "VERTICAL_CHECKERBOARD": VERTICAL_CHECKERBOARD,
            "VERTICAL_LINES": VERTICAL_LINES,
            "VERTICAL_ROTATE": VERTICAL_ROTATE,
            "VERTICAL_STRETCH": VERTICAL_STRETCH,
            "VERTICAL_STRIPES": VERTICAL_STRIPES,
            "WAVYLINE_FROM_BOTTOM": WAVYLINE_FROM_BOTTOM,
            "WAVYLINE_FROM_LEFT": WAVYLINE_FROM_LEFT,
            "WAVYLINE_FROM_RIGHT": WAVYLINE_FROM_RIGHT,
            "WAVYLINE_FROM_TOP": WAVYLINE_FROM_TOP,
            "ZOOM_IN": ZOOM_IN,
            "ZOOM_IN_FROM_BOTTOM": ZOOM_IN_FROM_BOTTOM,
            "ZOOM_IN_FROM_CENTER": ZOOM_IN_FROM_CENTER,
            "ZOOM_IN_FROM_LEFT": ZOOM_IN_FROM_LEFT,
            "ZOOM_IN_FROM_LOWERLEFT": ZOOM_IN_FROM_LOWERLEFT,
            "ZOOM_IN_FROM_LOWERRIGHT": ZOOM_IN_FROM_LOWERRIGHT,
            "ZOOM_IN_FROM_RIGHT": ZOOM_IN_FROM_RIGHT,
            "ZOOM_IN_FROM_TOP": ZOOM_IN_FROM_TOP,
            "ZOOM_IN_FROM_UPPERLEFT": ZOOM_IN_FROM_UPPERLEFT,
            "ZOOM_IN_FROM_UPPERRIGHT": ZOOM_IN_FROM_UPPERRIGHT,
            "ZOOM_IN_SMALL": ZOOM_IN_SMALL,
            "ZOOM_IN_SPIRAL": ZOOM_IN_SPIRAL,
            "ZOOM_OUT": ZOOM_OUT,
            "ZOOM_OUT_FROM_BOTTOM": ZOOM_OUT_FROM_BOTTOM,
            "ZOOM_OUT_FROM_CENTER": ZOOM_OUT_FROM_CENTER,
            "ZOOM_OUT_FROM_LEFT": ZOOM_OUT_FROM_LEFT,
            "ZOOM_OUT_FROM_LOWERLEFT": ZOOM_OUT_FROM_LOWERLEFT,
            "ZOOM_OUT_FROM_LOWERRIGHT": ZOOM_OUT_FROM_LOWERRIGHT,
            "ZOOM_OUT_FROM_RIGHT": ZOOM_OUT_FROM_RIGHT,
            "ZOOM_OUT_FROM_TOP": ZOOM_OUT_FROM_TOP,
            "ZOOM_OUT_FROM_UPPERLEFT": ZOOM_OUT_FROM_UPPERLEFT,
            "ZOOM_OUT_FROM_UPPERRIGHT": ZOOM_OUT_FROM_UPPERRIGHT,
            "ZOOM_OUT_SMALL": ZOOM_OUT_SMALL,
            "ZOOM_OUT_SPIRAL": ZOOM_OUT_SPIRAL,
        }
        result = type('AnimationEffect', (object,), _dict)
        return result

    AnimationEffect = _get_enum()
else:
    from ...lo.presentation.animation_effect import AnimationEffect as AnimationEffect

__all__ = ['AnimationEffect']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.chart2.axis import Axis as Axis
from ...dyn.chart2.axis_orientation import AxisOrientation as AxisOrientation
from ...dyn.chart2.axis_type import AxisType as AxisType
from ...dyn.chart2.axis_type import AxisTypeEnum as AxisTypeEnum
from ...dyn.chart2.candle_stick_chart_type import CandleStickChartType as CandleStickChartType
from ...dyn.chart2.cartesian_coordinate_system2d import CartesianCoordinateSystem2d as CartesianCoordinateSystem2d
from ...dyn.chart2.cartesian_coordinate_system3d import CartesianCoordinateSystem3d as CartesianCoordinateSystem3d
from ...dyn.chart2.chart_document import ChartDocument as ChartDocument
from ...dyn.chart2.chart_document_wrapper import ChartDocumentWrapper as ChartDocumentWrapper
from ...dyn.chart2.chart_type import ChartType as ChartType
from ...dyn.chart2.chart_type_manager import ChartTypeManager as ChartTypeManager
from ...dyn.chart2.chart_type_template import ChartTypeTemplate as ChartTypeTemplate
from ...dyn.chart2.coordinate_system import CoordinateSystem as CoordinateSystem
from ...dyn.chart2.coordinate_system_type import CoordinateSystemType as CoordinateSystemType
from ...dyn.chart2.coordinate_system_type_id import CoordinateSystemTypeID as CoordinateSystemTypeID
from ...dyn.chart2.curve_style import CurveStyle as CurveStyle
from ...dyn.chart2.data_point import DataPoint as DataPoint
from ...dyn.chart2.data_point_custom_label_field import DataPointCustomLabelField as DataPointCustomLabelField
from ...dyn.chart2.data_point_custom_label_field_type import DataPointCustomLabelFieldType as DataPointCustomLabelFieldType
from ...dyn.chart2.data_point_geometry3_d import DataPointGeometry3D as DataPointGeometry3D
from ...dyn.chart2.data_point_geometry3_d import DataPointGeometry3DEnum as DataPointGeometry3DEnum
from ...dyn.chart2.data_point_label import DataPointLabel as DataPointLabel
from ...dyn.chart2.data_point_properties import DataPointProperties as DataPointProperties
from ...dyn.chart2.data_series import DataSeries as DataSeries
from ...dyn.chart2.diagram import Diagram as Diagram
from ...dyn.chart2.error_bar import ErrorBar as ErrorBar
from ...dyn.chart2.exponential_regression_curve import ExponentialRegressionCurve as ExponentialRegressionCurve
from ...dyn.chart2.exponential_scaling import ExponentialScaling as ExponentialScaling
from ...dyn.chart2.fill_bitmap import FillBitmap as FillBitmap
from ...dyn.chart2.formatted_string import FormattedString as FormattedString
from ...dyn.chart2.grid_properties import GridProperties as GridProperties
from ...dyn.chart2.increment_data import IncrementData as IncrementData
from ...dyn.chart2.interpreted_data import InterpretedData as InterpretedData
from ...dyn.chart2.legend import Legend as Legend
from ...dyn.chart2.legend_position import LegendPosition as LegendPosition
from ...dyn.chart2.light_source import LightSource as LightSource
from ...dyn.chart2.linear_regression_curve import LinearRegressionCurve as LinearRegressionCurve
from ...dyn.chart2.linear_scaling import LinearScaling as LinearScaling
from ...dyn.chart2.logarithmic_regression_curve import LogarithmicRegressionCurve as LogarithmicRegressionCurve
from ...dyn.chart2.logarithmic_scaling import LogarithmicScaling as LogarithmicScaling
from ...dyn.chart2.logic_target_model import LogicTargetModel as LogicTargetModel
from ...dyn.chart2.moving_average_regression_curve import MovingAverageRegressionCurve as MovingAverageRegressionCurve
from ...dyn.chart2.moving_average_type import MovingAverageType as MovingAverageType
from ...dyn.chart2.moving_average_type import MovingAverageTypeEnum as MovingAverageTypeEnum
from ...dyn.chart2.pie_chart_offset_mode import PieChartOffsetMode as PieChartOffsetMode
from ...dyn.chart2.polar_coordinate_system2d import PolarCoordinateSystem2d as PolarCoordinateSystem2d
from ...dyn.chart2.polar_coordinate_system3d import PolarCoordinateSystem3d as PolarCoordinateSystem3d
from ...dyn.chart2.polynomial_regression_curve import PolynomialRegressionCurve as PolynomialRegressionCurve
from ...dyn.chart2.potential_regression_curve import PotentialRegressionCurve as PotentialRegressionCurve
from ...dyn.chart2.power_scaling import PowerScaling as PowerScaling
from ...dyn.chart2.property_pool import PropertyPool as PropertyPool
from ...dyn.chart2.regression_curve import RegressionCurve as RegressionCurve
from ...dyn.chart2.regression_curve_equation import RegressionCurveEquation as RegressionCurveEquation
from ...dyn.chart2.regression_equation import RegressionEquation as RegressionEquation
from ...dyn.chart2.relative_position import RelativePosition as RelativePosition
from ...dyn.chart2.relative_size import RelativeSize as RelativeSize
from ...dyn.chart2.scale_data import ScaleData as ScaleData
from ...dyn.chart2.scaling import Scaling as Scaling
from ...dyn.chart2.stacking_direction import StackingDirection as StackingDirection
from ...dyn.chart2.standard_diagram_creation_parameters import StandardDiagramCreationParameters as StandardDiagramCreationParameters
from ...dyn.chart2.sub_increment import SubIncrement as SubIncrement
from ...dyn.chart2.symbol import Symbol as Symbol
from ...dyn.chart2.symbol_style import SymbolStyle as SymbolStyle
from ...dyn.chart2.tickmark_style import TickmarkStyle as TickmarkStyle
from ...dyn.chart2.tickmark_style import TickmarkStyleEnum as TickmarkStyleEnum
from ...dyn.chart2.title import Title as Title
from ...dyn.chart2.transparency_style import TransparencyStyle as TransparencyStyle
from ...dyn.chart2.x_any_description_access import XAnyDescriptionAccess as XAnyDescriptionAccess
from ...dyn.chart2.x_axis import XAxis as XAxis
from ...dyn.chart2.x_chart_document import XChartDocument as XChartDocument
from ...dyn.chart2.x_chart_shape import XChartShape as XChartShape
from ...dyn.chart2.x_chart_shape_container import XChartShapeContainer as XChartShapeContainer
from ...dyn.chart2.x_chart_type import XChartType as XChartType
from ...dyn.chart2.x_chart_type_container import XChartTypeContainer as XChartTypeContainer
from ...dyn.chart2.x_chart_type_manager import XChartTypeManager as XChartTypeManager
from ...dyn.chart2.x_chart_type_template import XChartTypeTemplate as XChartTypeTemplate
from ...dyn.chart2.x_color_scheme import XColorScheme as XColorScheme
from ...dyn.chart2.x_coordinate_system import XCoordinateSystem as XCoordinateSystem
from ...dyn.chart2.x_coordinate_system_container import XCoordinateSystemContainer as XCoordinateSystemContainer
from ...dyn.chart2.x_data_interpreter import XDataInterpreter as XDataInterpreter
from ...dyn.chart2.x_data_point_custom_label_field import XDataPointCustomLabelField as XDataPointCustomLabelField
from ...dyn.chart2.x_data_provider_access import XDataProviderAccess as XDataProviderAccess
from ...dyn.chart2.x_data_series import XDataSeries as XDataSeries
from ...dyn.chart2.x_data_series_container import XDataSeriesContainer as XDataSeriesContainer
from ...dyn.chart2.x_default_size_transmitter import XDefaultSizeTransmitter as XDefaultSizeTransmitter
from ...dyn.chart2.x_diagram import XDiagram as XDiagram
from ...dyn.chart2.x_diagram_provider import XDiagramProvider as XDiagramProvider
from ...dyn.chart2.x_formatted_string import XFormattedString as XFormattedString
from ...dyn.chart2.x_formatted_string2 import XFormattedString2 as XFormattedString2
from ...dyn.chart2.x_internal_data_provider import XInternalDataProvider as XInternalDataProvider
from ...dyn.chart2.x_labeled import XLabeled as XLabeled
from ...dyn.chart2.x_legend import XLegend as XLegend
from ...dyn.chart2.x_regression_curve import XRegressionCurve as XRegressionCurve
from ...dyn.chart2.x_regression_curve_calculator import XRegressionCurveCalculator as XRegressionCurveCalculator
from ...dyn.chart2.x_regression_curve_container import XRegressionCurveContainer as XRegressionCurveContainer
from ...dyn.chart2.x_scaling import XScaling as XScaling
from ...dyn.chart2.x_target import XTarget as XTarget
from ...dyn.chart2.x_time_based import XTimeBased as XTimeBased
from ...dyn.chart2.x_title import XTitle as XTitle
from ...dyn.chart2.x_titled import XTitled as XTitled
from ...dyn.chart2.x_transformation import XTransformation as XTransformation



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.table
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_cell_range import XCellRange as XCellRange_a2f70ad5

class TableRow(XPropertySet_bc180bfa, XCellRange_a2f70ad5):
    """
    Service Class

    represents a special cell range containing all cells of a single specific row in a table or spreadsheet.

    See Also:
        `API TableRow <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.TableRow'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Height(self) -> int:
        """
        contains the height of the row (in 1/100 mm).
        
        When hidden, it returns the height which the row would have, if it were visible.
        """

    @abstractproperty
    def IsStartOfNewPage(self) -> bool:
        """
        is TRUE, if there is a manual vertical page break attached to the row.
        """

    @abstractproperty
    def IsVisible(self) -> bool:
        """
        is TRUE, if the row is visible.
        """

    @abstractproperty
    def OptimalHeight(self) -> bool:
        """
        is TRUE, if the row always keeps its optimal height.
        """



__all__ = ['TableRow']

